@@ -10,6 +10,6 @@ declara.rows = [
 declara.name = "Jouw Naam"
 declara.iban = "NL12INGB2590295195"
 
-declara.attachments = ["bonnetje_benzine.jpg", "bonnetje_bier.jpg"]
+declara.attachments = ["https://i.imgur.com/Mw5MEyq.jpeg"]
 
-declara.produce()
+declara.send_email()
